@@ -5,7 +5,7 @@ from __future__ import division
 import os
 import subprocess
 
-import pwnlib
+import pwnlib.args
 pwnlib.args.free_form = False
 
 from pwn import *
@@ -29,4 +29,4 @@ def main(a):
 	log.info("Pwntools v%s" % version)
 
 if __name__ == '__main__':
-    pwnlib.commandline.common.main(__file__)
+    pwnlib.commandline.common.main(__file__, main)
